@@ -14,6 +14,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import logging
 
+import six
 from opaque_keys.edx.keys import CourseKey
 
 from django.core.management.base import BaseCommand
@@ -59,8 +60,9 @@ class Command(BaseCommand):
         if options['all']:
             options['course_keys'] = BlockCompletion.objects.values_list('course_key').distinct()
         CourseEnrollment = compat.course_enrollment_model()  # pylint: disable=invalid-name
-        for course_str in options['course_keys']:
-            course = CourseKey.from_string(course_str)
+        for course in options['course_keys']:
+            if isinstance(course, six.string_types):
+                course = CourseKey.from_string(course)
             all_enrollments = CourseEnrollment.objects.filter(course=course).select_related('user')
             StaleCompletion.objects.bulk_create(
                 (
